summaryrefslogtreecommitdiffstats
path: root/lib/plugin.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-01 00:37:32 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-01 00:37:32 +0000
commitf6f9c296c3f9d39a8c3d0ee64a542a47f450be28 (patch)
treed38fce8091ce66977004a5cb115768c7810aee30 /lib/plugin.h
parente340db64991a06761aa6395ffe760b53e4c1dfbc (diff)
downloadkpilot-f6f9c296c3f9d39a8c3d0ee64a542a47f450be28.tar.gz
kpilot-f6f9c296c3f9d39a8c3d0ee64a542a47f450be28.zip
TQt4 port kpilot
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kpilot@1238903 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/plugin.h')
-rw-r--r--lib/plugin.h20
1 files changed, 12 insertions, 8 deletions
diff --git a/lib/plugin.h b/lib/plugin.h
index 5300c58..817d753 100644
--- a/lib/plugin.h
+++ b/lib/plugin.h
@@ -75,15 +75,16 @@ namespace Pilot
* seems a little foolish.
*
*/
-class KDE_EXPORT ConduitConfigBase : public QObject
+class KDE_EXPORT ConduitConfigBase : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor. Creates a conduit configuration support object
* with the given parent @p parent and name (optional) @p n.
*/
- ConduitConfigBase(TQWidget *parent=0L, const char *n=0L);
+ ConduitConfigBase(TQWidget *tqparent=0L, const char *n=0L);
/** Destructor. */
virtual ~ConduitConfigBase();
@@ -151,10 +152,10 @@ public:
* application's icon. This widget can be used pretty much
* anywhere. Copied from KAboutDialog, mostly.
*
* @param parent The widget that holds the about widget.
* @param data The KAboutData that is used to populate the widget.
*/
- static TQWidget *aboutPage(TQWidget *parent, KAboutData *data=0L);
+ static TQWidget *aboutPage(TQWidget *tqparent, KAboutData *data=0L);
protected:
/**
@@ -260,6 +261,7 @@ private:
class KDE_EXPORT ConduitAction : public SyncAction
{
Q_OBJECT
+ TQ_OBJECT
public:
ConduitAction(KPilotLink *,
@@ -367,6 +369,7 @@ private:
class ConduitProxy : public ConduitAction
{
Q_OBJECT
+ TQ_OBJECT
public:
ConduitProxy(KPilotLink *,
@@ -387,7 +390,7 @@ protected:
/** A namespace containing only static helper methods. */
namespace PluginUtility
{
- /** Searches the argument list for --foo=bar and returns bar, TQString::null if not found.
+ /** Searches the argument list for --foo=bar and returns bar, TQString() if not found.
* Don't include the -- in the argname. */
TQString findArgument(const TQStringList &a, const TQString argname);
@@ -418,6 +421,7 @@ namespace PluginUtility
* class KPilotPlugin : public KLibFactory
* {
* Q_OBJECT
+ TQ_OBJECT
*
* public:
* KPilotPlugin(TQObject * = 0L,const char * = 0L) ;
@@ -440,9 +444,9 @@ namespace PluginUtility
*
* <pre>
* protected:
-* virtual TQObject* createObject( TQObject* parent = 0,
+* virtual TQObject* createObject( TQObject* tqparent = 0,
* const char* name = 0,
-* const char* classname = "TQObject",
+* const char* classname = TQOBJECT_OBJECT_NAME_STRING,
* const TQStringList &args = TQStringList() );
* </pre>
*
@@ -75,15 +75,16 @@ namespace Pilot
/**
* Constructor. Creates a conduit configuration support object
- * with the given parent @p parent and name (optional) @p n.
+ * with the given tqparent @p tqparent and name (optional) @p n.
*/
@@ -151,10 +152,10 @@ public:
* anywhere. Copied from KAboutDialog, mostly.
*
- * @param parent The widget that holds the about widget.
+ * @param tqparent The widget that holds the about widget.
* @param data The KAboutData that is used to populate the widget.
*/